C
C This file is issued from the MODULEF library, but has been 
C subsequently modified
C
      SUBROUTINE READRE (ITYPE,NOM,IADRES,L,M,NSORT)
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C BUT :
C     ALLOCATION DYNAMIQUE - RE-ALLOUER UN TABLEAU
C
C PARAMETRES :
C     ITYPE  : TYPE DU TABLEAU (CF ZALDY1)
C     NOM    : NOM DU TABLEAU
C     IADRES : EN SORTIE, INDICE DU TABLEAU DANS LE SUPER-TABLEAU
C     L      : LONGUEUR EN MOTS DU TABLEAU
C     M      : SUPER-TABLEAU
C     NSORTI : 1 LE TABLEAU EXISTAIT AVEC MEME LONGUEUR ET MEME TYPE
C              0 SINON
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C PROGRAMMEUR : F. HECHT - INRIA - AVRIL 86
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      CHARACTER*(*) NOM
      DIMENSION M(*)
      IF (L .EQ. 0) THEN
        IMPRIM = IINFO('I')
        WRITE(IMPRIM,100) NOM
        IADRES = 1
        RETURN
      ENDIF
      CALL ZALDY1('READRE',ITYPE,NOM,IADRES,L,M,NSORT)
C
C 100 FORMAT(/' ** WARNING READRE : ARRAY ',A,' HAS ZERO LENGTH '       #GB
C    +   ,'WITH ADRES SET TO 1' /)                                      #GB
C
  100 FORMAT(/' ** WARNING READRE : TABLEAU ',A,' DE LONGUEUR NULLE '   #F
     +   ,'SON ADRESSE EST MISE A 1' /)                                 #F
C
      END
